@@ -1,11 +1,10 @@
-# -*- coding: utf-8 -*-
 """
     flaskext.autoindex
     ~~~~~~~~~~~~~~~~~~
 
     A mod_autoindex for `Flask <http://flask.pocoo.org/>`_.
 
-    :copyright: (c) 2010 by Lee Heung-sub.
+    :copyright: (c) 2010-2011 by Heungsub Lee.
     :license: BSD, see LICENSE for more details.
 """
 import os.path
@@ -28,7 +27,7 @@ class AutoIndex(object):
     example::
 
         app = Flask(__name__)
-        idx = AutoIndex(app, '/home/someone/public_html', add_url_rules=True)
+        AutoIndex(app, '/home/someone/public_html', add_url_rules=True)
 
     :param base: a flask application
     :param browse_root: a path which is served by root address.
@@ -203,6 +202,7 @@ class AutoIndex(object):
 
 
 class AutoIndexApplication(AutoIndex):
+    """An AutoIndex which supports flask applications."""
 
     template_prefix = ''
 
@@ -215,6 +215,10 @@ class AutoIndexApplication(AutoIndex):
 
 
 class AutoIndexBlueprint(AutoIndex):
+    """An AutoIndex which supports flask blueprints.
+
+    .. versionadded:: 0.3.1
+    """
 
     def __init__(self, blueprint, browse_root=None, **silk_options):
         super(AutoIndexBlueprint, self).__init__(blueprint, browse_root,
@@ -229,6 +233,11 @@ class AutoIndexBlueprint(AutoIndex):
 
 
 class AutoIndexModule(AutoIndexBlueprint):
+    """Deprecated module support.
+
+    .. versionchanged:: 0.3.1
+       ``AutoIndexModule`` was deprecated. Use ``AutoIndexBlueprint`` instead.
+    """
 
     def __init__(self, *args, **kwargs):
         import warnings
